# Contributing to Wix Media Platform Python SDK

## Clone Repository

```bash
git clone git@github.com:wix/media-platform-python-sdk.git

cd media-platform-python-sdk
```

## Project Setup

### Requirements

- Python >=3.7
- virtualenv

### Running Virtualenv

```bash
virtualenv venv

source venv/bin/activate
```

### Installing Requirements

```bash
pip install -e .
```

### Running Tests

```bash
python setup.py test
```